@@ -1,11 +1,11 @@
-;;; phpstan.el --- Interface to PHPStan              -*- lexical-binding: t; -*-
+;;; phpstan.el --- Interface to PHPStan (PHP static analyzer)  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2025  Friends of Emacs-PHP development
 
 ;; Author: USAMI Kenta <tadsan@zonu.me>
 ;; Created: 15 Mar 2018
-;; Package-Version: 0.9.0
-;; Package-Revision: 206573c8de58
+;; Package-Version: 20250930.1139
+;; Package-Revision: 07ef7531f2ec
 ;; Keywords: tools, php
 ;; Homepage: https://github.com/emacs-php/phpstan.el
 ;; Package-Requires: ((emacs "25.1") (compat "30") (php-mode "1.22.3") (php-runtime "0.2"))
@@ -63,6 +63,7 @@
   (require 'compat nil t)
   (require 'php)
   (require 'json)
+  (require 'tramp)
   (declare-function 'tramp-dissect-file-name "tramp" '(name &optional nodefault))
   (declare-function 'tramp-file-name-localname "tamp" '(cl-x)))
 
@@ -517,6 +518,7 @@ it returns the value of `SOURCE' as it is."
                            "--xdebug"))
              (list phpstan--use-xdebug-option))
             (phpstan-use-xdebug-option (list "--xdebug")))
+           options
            (when editor
              (let ((original-file (plist-get editor :original-file)))
                (cond
@@ -527,8 +529,7 @@ it returns the value of `SOURCE' as it is."
                        "--instead-of" original-file
                        "--" original-file))
                 ((list "--" (funcall (plist-get editor :inplace)))))))
-           options
-           (and args (cons "--" args)))))
+           (if editor args (cons "--" args)))))
 
 (defun phpstan-update-ignorebale-errors-from-json-buffer (errors)
   "Update `phpstan--ignorable-errors' variable by ERRORS."
